# GraphGallery

A gallery of state-of-the-arts graph neural networks.. 

Implemented with Tensorflow 2.x.

This repo aims to achieve 4 goals:
+ Similar (or higher) performance with the corresponding papers
+ Faster implementation of training and testing
+ Simple and convenient to use, high scalability
+ Easy to read source codes

# Requirements

+ python>=3.7
+ tensorflow>=2.1 (2.1 is recommended)
+ networkx==2.3
+ scipy>=1.4.1
+ sklearn>=0.22
+ numpy>=1.18.1
+ numba>=0.48
+ gensim>=3.8.1

Extral packages (not necessary）:

+ metis==0.2a4
+ texttable

# Install
```bash
pip install graphgallery -U
```


